JourneyMode enum
Different Bank Journey modes
- Inheritance
- Available extensions
Values
- NORMAL → const JourneyMode
-
Specifies that the SDK shows normally journey
- MULTI_PDF → const JourneyMode
-
Specifies that the SDK shows multi pdf journey
- MULTI_BANKING → const JourneyMode
-
Specifies that the SDK shows multi banking journey
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
Available on JourneyMode, provided by the ModeExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
JourneyMode> - A constant List of the values in this enum, in order of their declaration.